@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """Base class for Telegram Objects."""
 import contextlib
-import datetime
+import datetime as dtm
 import inspect
 import json
 from collections.abc import Iterator, Mapping, Sized
@@ -377,23 +377,20 @@ class TelegramObject:
         return result
 
     @staticmethod
-    def _parse_data(data: Optional[JSONDict]) -> Optional[JSONDict]:
+    def _parse_data(data: JSONDict) -> JSONDict:
         """Should be called by subclasses that override de_json to ensure that the input
         is not altered. Whoever calls de_json might still want to use the original input
         for something else.
         """
-        return None if data is None else data.copy()
+        return data.copy()
 
     @classmethod
     def _de_json(
         cls: type[Tele_co],
-        data: Optional[JSONDict],
+        data: JSONDict,
         bot: Optional["Bot"],
         api_kwargs: Optional[JSONDict] = None,
-    ) -> Optional[Tele_co]:
-        if data is None:
-            return None
-
+    ) -> Tele_co:
         # try-except is significantly faster in case we already have a correct argument set
         try:
             obj = cls(**data, api_kwargs=api_kwargs)
@@ -417,9 +414,7 @@ class TelegramObject:
         return obj
 
     @classmethod
-    def de_json(
-        cls: type[Tele_co], data: Optional[JSONDict], bot: Optional["Bot"] = None
-    ) -> Optional[Tele_co]:
+    def de_json(cls: type[Tele_co], data: JSONDict, bot: Optional["Bot"] = None) -> Tele_co:
         """Converts JSON data to a Telegram object.
 
         Args:
@@ -438,7 +433,7 @@ class TelegramObject:
 
     @classmethod
     def de_list(
-        cls: type[Tele_co], data: Optional[list[JSONDict]], bot: Optional["Bot"] = None
+        cls: type[Tele_co], data: list[JSONDict], bot: Optional["Bot"] = None
     ) -> tuple[Tele_co, ...]:
         """Converts a list of JSON objects to a tuple of Telegram objects.
 
@@ -459,10 +454,7 @@ class TelegramObject:
             A tuple of Telegram objects.
 
         """
-        if not data:
-            return ()
-
-        return tuple(obj for obj in (cls.de_json(d, bot) for d in data) if obj is not None)
+        return tuple(cls.de_json(d, bot) for d in data)
 
     @contextmanager
     def _unfrozen(self: Tele_co) -> Iterator[Tele_co]:
@@ -634,9 +626,9 @@ class TelegramObject:
                         val.append(item)
                 out[key] = val
 
-            elif isinstance(value, datetime.datetime):
+            elif isinstance(value, dtm.datetime):
                 out[key] = to_timestamp(value)
-            elif isinstance(value, datetime.timedelta):
+            elif isinstance(value, dtm.timedelta):
                 out[key] = value.total_seconds()
 
         for key in pop_keys:
