@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2024
+# Copyright (C) 2015-2025
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -34,6 +34,9 @@ This module contains filters for use with :class:`telegram.ext.MessageHandler`,
        * Filters which do both (like ``Filters.text``) are now split as ready-to-use version
          ``filters.TEXT`` and class version ``filters.Text(...)``.
 
+.. versionchanged:: 22.0
+    Removed deprecated attribute `CHAT`.
+
 """
 
 __all__ = (
@@ -43,7 +46,6 @@ __all__ = (
     "AUDIO",
     "BOOST_ADDED",
     "CAPTION",
-    "CHAT",
     "COMMAND",
     "CONTACT",
     "EFFECT_ID",
@@ -104,22 +106,9 @@ __all__ = (
 import mimetypes
 import re
 from abc import ABC, abstractmethod
-from typing import (
-    Collection,
-    Dict,
-    FrozenSet,
-    Iterable,
-    List,
-    Match,
-    NoReturn,
-    Optional,
-    Pattern,
-    Sequence,
-    Set,
-    Tuple,
-    Union,
-    cast,
-)
+from collections.abc import Collection, Iterable, Sequence
+from re import Match, Pattern
+from typing import NoReturn, Optional, Union, cast
 
 from telegram import Chat as TGChat
 from telegram import (
@@ -320,7 +309,7 @@ class MessageFilter(BaseFilter):
             update (:class:`telegram.Update`): The update to check.
 
         Returns:
-            :obj:`bool` | Dict[:obj:`str`, :obj:`list`] | :obj:`None`: If the update should be
+            :obj:`bool` | dict[:obj:`str`, :obj:`list`] | :obj:`None`: If the update should be
             handled by this filter, returns :obj:`True` or a dict with lists, in case the filter
             is a data filter. If the update should not be handled by this filter, :obj:`False` or
             :obj:`None`.
@@ -361,7 +350,7 @@ class UpdateFilter(BaseFilter):
             update (:class:`telegram.Update`): The update to check.
 
         Returns:
-            :obj:`bool` | Dict[:obj:`str`, :obj:`list`] | :obj:`None`: If the update should be
+            :obj:`bool` | dict[:obj:`str`, :obj:`list`] | :obj:`None`: If the update should be
             handled by this filter, returns :obj:`True` or a dict with lists, in case the filter
             is a data filter. If the update should not be handled by this filter, :obj:`False` or
             :obj:`None`.
@@ -441,7 +430,7 @@ class _MergedFilter(UpdateFilter):
             self.data_filter = True
 
     @staticmethod
-    def _merge(base_output: Union[bool, Dict], comp_output: Union[bool, Dict]) -> FilterDataDict:
+    def _merge(base_output: Union[bool, dict], comp_output: Union[bool, dict]) -> FilterDataDict:
         base = base_output if isinstance(base_output, dict) else {}
         comp = comp_output if isinstance(comp_output, dict) else {}
         for k in comp:
@@ -585,13 +574,13 @@ class Caption(MessageFilter):
         :attr:`telegram.ext.filters.CAPTION`
 
     Args:
-        strings (List[:obj:`str`] | Tuple[:obj:`str`], optional): Which captions to allow. Only
+        strings (list[:obj:`str`] | tuple[:obj:`str`], optional): Which captions to allow. Only
             exact matches are allowed. If not specified, will allow any message with a caption.
     """
 
     __slots__ = ("strings",)
 
-    def __init__(self, strings: Optional[Union[List[str], Tuple[str, ...]]] = None):
+    def __init__(self, strings: Optional[Union[list[str], tuple[str, ...]]] = None):
         self.strings: Optional[Sequence[str]] = strings
         super().__init__(name=f"filters.Caption({strings})" if strings else "filters.CAPTION")
 
@@ -660,7 +649,7 @@ class CaptionRegex(MessageFilter):
         self.pattern: Pattern[str] = pattern
         super().__init__(name=f"filters.CaptionRegex({self.pattern})", data_filter=True)
 
-    def filter(self, message: Message) -> Optional[Dict[str, List[Match[str]]]]:
+    def filter(self, message: Message) -> Optional[dict[str, list[Match[str]]]]:
         if message.caption and (match := self.pattern.search(message.caption)):
             return {"matches": [match]}
         return {}
@@ -686,8 +675,8 @@ class _ChatUserBaseFilter(MessageFilter, ABC):
         self._username_name: str = "username"
         self.allow_empty: bool = allow_empty
 
-        self._chat_ids: Set[int] = set()
-        self._usernames: Set[str] = set()
+        self._chat_ids: set[int] = set()
+        self._usernames: set[str] = set()
 
         self._set_chat_ids(chat_id)
         self._set_usernames(username)
@@ -712,7 +701,7 @@ class _ChatUserBaseFilter(MessageFilter, ABC):
         self._usernames = set(parse_username(username))
 
     @property
-    def chat_ids(self) -> FrozenSet[int]:
+    def chat_ids(self) -> frozenset[int]:
         return frozenset(self._chat_ids)
 
     @chat_ids.setter
@@ -720,7 +709,7 @@ class _ChatUserBaseFilter(MessageFilter, ABC):
         self._set_chat_ids(chat_id)
 
     @property
-    def usernames(self) -> FrozenSet[str]:
+    def usernames(self) -> frozenset[str]:
         """Which username(s) to allow through.
 
         Warning:
@@ -872,21 +861,6 @@ class Chat(_ChatUserBaseFilter):
         return super()._remove_chat_ids(chat_id)
 
 
-class _Chat(MessageFilter):
-    __slots__ = ()
-
-    def filter(self, message: Message) -> bool:
-        return bool(message.chat)
-
-
-CHAT = _Chat(name="filters.CHAT")
-"""This filter filters *any* message that has a :attr:`telegram.Message.chat`.
-
-.. deprecated:: 20.8
-   This filter has no effect since :attr:`telegram.Message.chat` is always present.
-"""
-
-
 class ChatType:  # A convenience namespace for Chat types.
     """Subset for filtering the type of chat.
 
@@ -1617,7 +1591,7 @@ class Language(MessageFilter):
             lang = cast(str, lang)
             self.lang: Sequence[str] = [lang]
         else:
-            lang = cast(List[str], lang)
+            lang = cast(list[str], lang)
             self.lang = lang
         super().__init__(name=f"filters.Language({self.lang})")
 
@@ -1795,7 +1769,7 @@ class Regex(MessageFilter):
         self.pattern: Pattern[str] = pattern
         super().__init__(name=f"filters.Regex({self.pattern})", data_filter=True)
 
-    def filter(self, message: Message) -> Optional[Dict[str, List[Match[str]]]]:
+    def filter(self, message: Message) -> Optional[dict[str, list[Match[str]]]]:
         if message.text and (match := self.pattern.search(message.text)):
             return {"matches": [match]}
         return {}
@@ -1928,6 +1902,9 @@ class StatusUpdate:
 
     Caution:
         ``filters.StatusUpdate`` itself is *not* a filter, but just a convenience namespace.
+
+    .. versionchanged:: 22.0
+        Removed deprecated attribute `USER_SHARED`.
     """
 
     __slots__ = ()
@@ -1961,7 +1938,6 @@ class StatusUpdate:
                 or StatusUpdate.PROXIMITY_ALERT_TRIGGERED.check_update(update)
                 or StatusUpdate.REFUNDED_PAYMENT.check_update(update)
                 or StatusUpdate.USERS_SHARED.check_update(update)
-                or StatusUpdate.USER_SHARED.check_update(update)
                 or StatusUpdate.VIDEO_CHAT_ENDED.check_update(update)
                 or StatusUpdate.VIDEO_CHAT_PARTICIPANTS_INVITED.check_update(update)
                 or StatusUpdate.VIDEO_CHAT_SCHEDULED.check_update(update)
@@ -2217,28 +2193,6 @@ class StatusUpdate:
     .. versionadded:: 21.4
     """
 
-    class _UserShared(MessageFilter):
-        __slots__ = ()
-
-        def filter(self, message: Message) -> bool:
-            return bool(message.api_kwargs.get("user_shared"))
-
-    USER_SHARED = _UserShared(name="filters.StatusUpdate.USER_SHARED")
-    """Messages that contain ``"user_shared"`` in :attr:`telegram.TelegramObject.api_kwargs`.
-
-    Warning:
-        This will only catch the legacy ``user_shared`` field, not the
-        new :attr:`telegram.Message.users_shared` attribute!
-
-    .. versionchanged:: 21.0
-       Now relies on :attr:`telegram.TelegramObject.api_kwargs` as the native attribute
-       ``Message.user_shared`` was removed.
-
-    .. versionadded:: 20.1
-    .. deprecated:: 20.8
-       Use :attr:`USERS_SHARED` instead.
-    """
-
     class _UsersShared(MessageFilter):
         __slots__ = ()
 
@@ -2440,7 +2394,7 @@ class SuccessfulPayment(MessageFilter):
         :attr:`telegram.ext.filters.SUCCESSFUL_PAYMENT`
 
     Args:
-        invoice_payloads (List[:obj:`str`] | Tuple[:obj:`str`], optional): Which
+        invoice_payloads (list[:obj:`str`] | tuple[:obj:`str`], optional): Which
             invoice payloads to allow. Only exact matches are allowed. If not
             specified, will allow any invoice payload.
 
@@ -2449,7 +2403,7 @@ class SuccessfulPayment(MessageFilter):
 
     __slots__ = ("invoice_payloads",)
 
-    def __init__(self, invoice_payloads: Optional[Union[List[str], Tuple[str, ...]]] = None):
+    def __init__(self, invoice_payloads: Optional[Union[list[str], tuple[str, ...]]] = None):
         self.invoice_payloads: Optional[Sequence[str]] = invoice_payloads
         super().__init__(
             name=(
@@ -2498,13 +2452,13 @@ class Text(MessageFilter):
           commands.
 
     Args:
-        strings (List[:obj:`str`] | Tuple[:obj:`str`], optional): Which messages to allow. Only
+        strings (list[:obj:`str`] | tuple[:obj:`str`], optional): Which messages to allow. Only
             exact matches are allowed. If not specified, will allow any text message.
     """
 
     __slots__ = ("strings",)
 
-    def __init__(self, strings: Optional[Union[List[str], Tuple[str, ...]]] = None):
+    def __init__(self, strings: Optional[Union[list[str], tuple[str, ...]]] = None):
         self.strings: Optional[Sequence[str]] = strings
         super().__init__(name=f"filters.Text({strings})" if strings else "filters.TEXT")
 
@@ -2694,7 +2648,7 @@ class User(_ChatUserBaseFilter):
         return message.from_user
 
     @property
-    def user_ids(self) -> FrozenSet[int]:
+    def user_ids(self) -> frozenset[int]:
         """
         Which user ID(s) to allow through.
 
@@ -2832,7 +2786,7 @@ class ViaBot(_ChatUserBaseFilter):
         return message.via_bot
 
     @property
-    def bot_ids(self) -> FrozenSet[int]:
+    def bot_ids(self) -> frozenset[int]:
         """
         Which bot ID(s) to allow through.
 
